@@ -4,7 +4,8 @@ knitr::opts_chunk$set(
   comment = "#>",
   out.width = "300px", fig.align = "center", dpi = 300
 )
-library(tidyverse)
+library(dplyr)
+library(ggplot2)
 theme_set(theme_bw())
 library(rticulate)
 
